import logging

from contrib.umws.umws_service import UMWebService

logger = logging.getLogger('umws.logger')


class SMSService(UMWebService):
    """ """
    settings_name = "SMS_SERVICE_CONFIG"

    def mask_number(self, number):
        """ Mask phone number to be used in logs.
            examples: '919999999' returns '91****999'
                      '+351919999999' returns '+35191****999'
                      '1234' returns '1234'
        """
        if len(number) > 8:
            prefix = number[:len(number) - 7]
            sufix = number[len(number) - 3:]
            return "%s****%s" % (prefix, sufix)
        return number

    def send_message(self, number, message, anonymous=False):
        """ Returns message id (int) """
        if self.in_debug():
            return "Success Message"
        client = self.get_client()
        try:
            msg_id = client.service.SendMessage(number, message, anonymous)
        except Exception as e:
            logger.critical(e, exc_info=True)
            logger.info("Send SMS Failed: message '%s' to '%s'",
                        message.encode('utf8'),
                        self.mask_number(str(number)))
            raise
        logger.info("Sent SMS message '%s' to '%s' with id (%s)",
                    message.encode('utf8'),
                    self.mask_number(str(number)),
                    str(msg_id))
        return msg_id

    def get_message_status(self, msgid):
        """ """
        if self.in_debug():
            return "sended"  # FIXME missing info
        client = self.get_client()
        status_msg = client.service.GetMessageStatus(msgid)
        return status_msg


sms_service = SMSService()
