import os

from django.core.urlresolvers import reverse_lazy

from evote.settings import *  # noqa


# Django settings

SITE_ID = 4

DEBUG = False
TEMPLATE_DEBUG = True
COMPRESS_OFFLINE = True

ALLOWED_HOSTS = [os.environ.get('SN_EVOTE')]
SECRET_KEY = os.environ.get('SECRET_KEY')
SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': os.environ.get('MYSQL_HOST'),
        'PORT': '',
        'OPTIONS': {
            'init_command': 'SET storage_engine=INNODB'
        },
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_URL'),
        "KEY_PREFIX": "evote",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

TEMPLATES[0]['APP_DIRS'] = False
TEMPLATES[0]['OPTIONS'].update({
    'loaders': [
        ('django.template.loaders.cached.Loader', [
            'django.template.loaders.filesystem.Loader',
            'django.template.loaders.app_directories.Loader',
        ]),
    ]
})


# Auth settings

LOGIN_URL = reverse_lazy("voters:login")
LOGOUT_URL = reverse_lazy("voters:logout")
LOGIN_REDIRECT_URL = reverse_lazy("voters:electoralprocess-list")

AUTHENTICATION_BACKENDS += [  # NOQA
    'django.contrib.auth.backends.ModelBackend',  # this is default
]


# Define the Celery Settings

CELERY_BROKER_URL = os.environ.get('BROKER_URL')


# sorl thumbnail settings

THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True
