import os

from django.core.urlresolvers import reverse_lazy

from evote.settings import *  # NOQA


# Django settings

SITE_ID = 10

DEBUG = False
TEMPLATE_DEBUG = True
COMPRESS_OFFLINE = True

ALLOWED_HOSTS = [os.environ.get('SN_EVOTE')]
SECRET_KEY = os.environ.get('SECRET_KEY')
SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': os.environ.get('MYSQL_HOST'),
        'PORT': '',
        'OPTIONS': {
            'init_command': 'SET storage_engine=INNODB'
        },
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_URL'),
        "KEY_PREFIX": "evote",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

TEMPLATES[0]['APP_DIRS'] = False
TEMPLATES[0]['OPTIONS'].update({
    'loaders': [
        ('django.template.loaders.cached.Loader', [
            'django.template.loaders.filesystem.Loader',
            'django.template.loaders.app_directories.Loader',
        ]),
    ]
})


# Auth settings

LOGIN_URL = reverse_lazy("voters:login")
LOGOUT_URL = reverse_lazy("adfsauth:ws-fed-signout")
LOGIN_REDIRECT_URL = reverse_lazy("voters:electoralprocess-list")

AUTHENTICATION_BACKENDS += [  # NOQA
    'contrib.adfsauth.backends.WSFedBackend',
]


# ADFS AUTH (WS-Fed Sign-In Protocol)

ADFS_WSFED = True
ADFS_WSFED_CONFIG = {
    'url': 'https://login.uminho.pt/adfs/ls/',
    'wtrealm': 'urn:uminho:evotum',
    'cert': os.path.join(PROJECT_DIR, '..', 'data', 'certs', 'um_adfs_autenticacao.pem'),  # noqa
    'claim_mapping': {'upn': 'upn',
                      'nome': 'name',
                      'email': 'email',
                      'telemovel': 'primary_phone',
                      'nic': 'nic'},
    "template_fail": 'voters/signin_fail.html',
    "post_response": "wresult"
}


# Define the Celery Settings
# http://docs.celeryproject.org/en/latest/userguide/configuration.html

CELERY_BROKER_URL = os.environ.get('BROKER_URL')


# sorl thumbnail settings

THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"


# WS UM Members

MEMBERS_SERVICE_CONFIG = {
    'url': 'https://ws.uminho.pt/ValidationServiceBasic/ValidationService.svc?wsdl',  # NOQA
    'login': os.environ.get('WS_MEMBERS_LOGIN'),
    'password': os.environ.get('WS_MEMBERS_PASSWORD')
}


# WS UM SMS Notifications

SMS_SERVICE_CONFIG = {
    'url': 'https://ws.uminho.pt/ShortMessageServiceBasic/SimpleMessageService.svc?wsdl',  # NOQA
    'login': os.environ.get('WS_SMS_LOGIN'),
    'password': os.environ.get('WS_SMS_PASSWORD')
}


# SAML Configurations

SAML.update({
    'idp_addr': 'https://autenticacao.gov.pt/fa/default.aspx'
})

EMAIL_FROM = 'info@uminho.pt'
DEFAULT_FROM_EMAIL = 'info@uminho.pt'
EVOTE_CONTACT_MAIL = 'info@uminho.pt'

EVOTE_MAILING_NOREPLY_DEFAULT = 'noreply@uminho.pt'
