from mock import Mock

from django.test import SimpleTestCase

# import evote.formats.en.formats as formats_en
import evote.formats.pt.formats as formats_pt


class CeleryTest(SimpleTestCase):

    def test_load_app(self):
        from evote.celery import app
        from celery import Celery
        self.assertIsInstance(app, Celery)


class WsgiTest(SimpleTestCase):

    def test_load_wsgi(self):
        from evote.wsgi import application
        self.assertIsNotNone(application._request_middleware)


class FormatsTest(SimpleTestCase):

    # def test_formats_en(self):

    #   self.assertEqual(formats_en.DATETIME_FORMAT, 'd-m-Y H:i')
    #   self.assertEqual(formats_en.DATETIME_INPUT_FORMATS, ['%d-%m-%Y %H:%M'])

    def test_formats_pt(self):
        self.assertEqual(formats_pt.DATETIME_FORMAT, 'd-m-Y H:i')
        self.assertEqual(formats_pt.DATETIME_INPUT_FORMATS, ['%d-%m-%Y %H:%M'])


class SettingsTest(SimpleTestCase):
    """ """

    def test_base_settings(self):
        """ """
        import evote.settings as base
        self.assertTrue(hasattr(base, "SECRET_KEY"))

    def test_docker_settings(self):
        """ """
        import evote.settings.docker as docker
        self.assertTrue(docker.DEBUG)

    def test_docker_admin_settings(self):
        """ """
        import evote.settings.docker.admin as admin
        self.assertEqual(admin.ROOT_URLCONF, 'evote.urls.admin')

    def test_docker_management_settings(self):
        """ """
        import evote.settings.docker.management as management
        self.assertEqual(management.ROOT_URLCONF, 'evote.urls.management')

    def test_docker_management_settings_show_in_history(self):
        """ """
        from evote.settings.docker.management import show_in_history
        user = Mock()
        user.is_electoral_member = True
        self.assertTrue(show_in_history(user))
        user.is_electoral_member = False
        self.assertFalse(show_in_history(user))

    def test_dev_settings(self):
        """ """
        import evote.settings.dev as dev
        self.assertFalse(dev.DEBUG)

    def test_dev_admin_settings(self):
        """ """
        import evote.settings.dev.admin as admin
        self.assertEqual(admin.ROOT_URLCONF, 'evote.urls.admin')

    def test_dev_management_settings(self):
        """ """
        import evote.settings.dev.management as management
        self.assertEqual(management.ROOT_URLCONF, 'evote.urls.management')

    def test_dev_management_settings_show_in_history(self):
        """ """
        from evote.settings.dev.management import show_in_history
        user = Mock()
        user.is_electoral_member = True
        self.assertTrue(show_in_history(user))
        user.is_electoral_member = False
        self.assertFalse(show_in_history(user))

    def test_staging_settings(self):
        """ """
        import evote.settings.staging as staging
        self.assertFalse(staging.DEBUG)

    def test_staging_admin_settings(self):
        """ """
        import evote.settings.staging.admin as admin
        self.assertEqual(admin.ROOT_URLCONF, 'evote.urls.admin')

    def test_staging_management_settings(self):
        """ """
        import evote.settings.staging.management as management
        self.assertEqual(management.ROOT_URLCONF, 'evote.urls.management')

    def test_staging_management_settings_show_in_history(self):
        """ """
        from evote.settings.staging.management import show_in_history
        user = Mock()
        user.is_electoral_member = True
        self.assertTrue(show_in_history(user))
        user.is_electoral_member = False
        self.assertFalse(show_in_history(user))

    def test_production_settings(self):
        """ """
        import evote.settings.production as production
        self.assertFalse(production.DEBUG)

    def test_production_admin_settings(self):
        """ """
        import evote.settings.production.admin as admin
        self.assertEqual(admin.ROOT_URLCONF, 'evote.urls.admin')

    def test_production_management_settings(self):
        """ """
        import evote.settings.production.management as management
        self.assertEqual(management.ROOT_URLCONF, 'evote.urls.management')

    def test_production_management_settings_show_in_history(self):
        """ """
        from evote.settings.production.management import show_in_history
        user = Mock()
        user.is_electoral_member = True
        self.assertTrue(show_in_history(user))
        user.is_electoral_member = False
        self.assertFalse(show_in_history(user))
