from __future__ import unicode_literals

import logging
from django.db import models
from django.utils.translation import ugettext_lazy as _

logger = logging.getLogger('evote.logger')


class SecretEntryManager(models.Manager):
    """ """
    def check_integrity(self):
        """Checks if all entries are submitted"""
        valid = True
        identifier_list = [a for (a, b) in self.model.Identifier.choices]
        identifier_names = [b for (a, b) in self.model.Identifier.choices]
        entries = self.filter(identifier__in=identifier_list)\
            .only('identifier', 'body')
        if not entries or len(entries) != len(identifier_list):
            valid = False
        for entry in entries:
            if entry.body is None or entry.body == '':
                valid = False
                logger.error("{}: {}".format(
                     _("Missing secret entry"),
                     identifier_names[entry.identifier]
                     )
                )
        if not valid:
            logger.critical(_("Failed secret entry integrity"))

        return valid
