from __future__ import unicode_literals

import os.path

from django.core.files.base import ContentFile
from django.utils import translation
from django.apps import apps
from django.conf import settings

from evotevotings.voters.importers import ElectoralRollImporter
from evotedocs.models import Document
from celery.utils.log import get_task_logger
from evote.celery import app

from .documents import ElectoralRollPdf


logger = get_task_logger(__name__)


@app.task(ignore_result=True, bind=True)
def import_electoral_roll(self, electoral_roll_id):
    """ """
    ElectoralRoll = apps.get_model("evotevoters.ElectoralRoll")  # noqa
    electoral_roll = ElectoralRoll.objects.select_related('election')\
        .get(pk=electoral_roll_id)
    # check if file exists in file system, if not, wait 5 seconds and check
    # again. This is necessary due to replication lsyncd
    if not os.path.exists(electoral_roll.document.document.path):
        # http://docs.celeryproject.org/en/latest/userguide/tasks.html#retrying
        raise self.retry(countdown=5, max_retries=3)
    try:
        importer = ElectoralRollImporter()
        importer.run(electoral_roll, electoral_roll.document.document)
    except:
        logger.exception("Error importing electoral roll")
        electoral_roll.imported = False
    else:
        electoral_roll.imported = True
    finally:
        electoral_roll.save(update_fields=['imported'])
    return electoral_roll.imported


@app.task(ignore_result=True)
def generate_electoral_roll_pdf(electoral_roll_id):
    """ """
    ElectoralRoll = apps.get_model("evotevoters.ElectoralRoll")  # noqa
    electoral_roll = ElectoralRoll.objects.select_related('election')\
        .get(pk=electoral_roll_id)
    languages = getattr(settings, 'LANGUAGES', None)
    for lang in languages:
        translation.activate(lang[0])
        try:
            pdf = ElectoralRollPdf().render(electoral_roll=electoral_roll)
            file = Document(designation='electoral_roll')
            file_name = "{}_{}.pdf".format(
                electoral_roll.election.identifier_en, electoral_roll.version)
            file.document.save(file_name, ContentFile(pdf), False)
            file.save()
            electoral_roll.pdf_document = file
            electoral_roll.save(update_fields=['pdf_document',
                                               'pdf_document_pt',
                                               'pdf_document_en'])
        except Exception:
            logger.exception("Error generating electoral roll pdf")
